@@ -9,7 +9,7 @@
  * in the Software without restriction, including without limitation the rights
  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following condition:
+ * furnished to do so, subject to the following conditions:
  * 
  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.
@@ -25,32 +25,38 @@
 #ifndef _CHANNEL_H_
 #define _CHANNEL_H_
 
-#include <sys/types.h>
-
-#define CHANNEL_TYPE_SESSION "session"
-#define CHANNEL_TYPE_X11 "x11"
+#include "includes.h"
+#include "buffer.h"
 
+/* channel->type values */
 #define CHANNEL_ID_NONE 0
 #define CHANNEL_ID_SESSION 1
 #define CHANNEL_ID_X11 2
+#define CHANNEL_ID_AGENT 3
 
 #define SSH_OPEN_ADMINISTRATIVELY_PROHIBITED    1
 #define SSH_OPEN_CONNECT_FAILED                 2
 #define SSH_OPEN_UNKNOWN_CHANNEL_TYPE           3
 #define SSH_OPEN_RESOURCE_SHORTAGE              4
 
-#define MAX_CHANNELS 1000 /* arbitrary */
+#define MAX_CHANNELS 400 /* arbitrary, includes each tcp/x11 connection */
 #define CHAN_EXTEND_SIZE 3 /* how many extra slots to add when we need more */
 
 #define RECV_MAXWINDOW 6000 /* tweak */
 #define RECV_MAXPACKET 1400 /* tweak */
 #define RECV_MINWINDOW 10000 /* when we get below this, we send a windowadjust*/
 
+/* a simpler way to define that we need code for listeners */
+#if !defined(DISABLE_X11FWD) || !defined(DISABLE_AUTHFWD) || \
+	!defined(DISABLE_TCPFWD)
+#define USE_LISTENERS
+#endif
+
 struct Channel {
 
 	unsigned int index; /* the local channel index */
 	unsigned int remotechan;
-	char type; /* session, x11, forwarded/direct-tcpip */
+	unsigned char type; /* CHANNEL_ID_SESSION, CHANNEL_ID_X11 etc */
 	unsigned int recvwindow, transwindow;
 	unsigned int recvmaxpacket, transmaxpacket;
 	void* typedata; /* a pointer to type specific data */
@@ -73,6 +79,8 @@ void chaninitialise();
 void chancleanup();
 void setchannelfds(fd_set *readfd, fd_set *writefd);
 void channelio(fd_set *readfd, fd_set *writefd);
+struct Channel* newchannel(unsigned int remotechan, unsigned char type, 
+		unsigned int transwindow, unsigned int transmaxpacket);
 
 void recv_msg_channel_open();
 void recv_msg_channel_request();
@@ -83,5 +91,10 @@ void recv_msg_channel_window_adjust();
 void recv_msg_channel_close();
 void recv_msg_channel_eof();
 
+#ifdef USE_LISTENERS
+int send_msg_channel_open_init(int fd, const char * typestring);
+void recv_msg_channel_open_confirmation();
+void recv_msg_channel_open_failure();
+#endif
 
 #endif /* _CHANNEL_H_ */
