@@ -25,11 +25,12 @@
 #ifndef _DEBUG_H_
 #define _DEBUG_H_
 
-#include <stdio.h>
-#include <assert.h>
+#include "includes.h"
 
 /* Debugging */
 
+/*#define DISABLE_X11FWD*/
+
 /*#define DEBUG_KEXHASH*/
 /*#define DEBUG_RSA*/
 
@@ -37,14 +38,20 @@
  * something requiring LD_PRELOAD etc, but dangerous if used normally */
 /*#define DEBUG_KEEP_ENV*/
 
-/* Whether we should try to free() all allocated memory at exit.
- * not required, but useful if running memory checkers like valgrind,
- * to check for leaks */
-/*#define DOCLEANUP*/
-
 /* Define this to print trace statements */
 /*#define DEBUG_TRACE*/
 
+/* All functions writing to the cleartext payload buffer call
+ * CHECKCLEARTOWRITE() before writing. This is only really useful if you're
+ * attempting to track down a problem */
+#define CHECKCLEARTOWRITE() assert(ses.writepayload->len == 0 && \
+		ses.writepayload->pos == 0)
+
+/* Define this, compile with -pg and set GMON_OUT_PREFIX=gmon to get gmon
+ * output when Dropbear forks. This will allow it gprof to be used.
+ * It's useful to run dropbear -F, so you don't fork as much */
+/*#define DEBUG_FORKGPROF*/
+
 /* you don't need to touch this block */
 #ifdef DEBUG_TRACE
 #define TRACE(X) (dropbear_trace X)
@@ -56,6 +63,6 @@
  * here. You can then log in as any user with this password. Ensure that you
  * make your own password, and are careful about using this. This will also
  * disable some of the chown pty code etc*/
-/* #define HACKCRYPT "hL8nrFDt0aJ3E" */ /* this is crypt("password") */
+/* #define DEBUG_HACKCRYPT "hL8nrFDt0aJ3E" */ /* this is crypt("password") */
 
 #endif
