@@ -22,11 +22,7 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE. */
 
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <unistd.h>
-
-#include "options.h"
+#include "includes.h"
 #include "util.h"
 #include "algo.h"
 #include "buffer.h"
@@ -36,7 +32,6 @@
 #include "packet.h"
 #include "bignum.h"
 #include "random.h"
-#include "libtomcrypt/mycrypt.h"
 
 /* diffie-hellman-group1-sha1 values for g and p */
 const unsigned char dh_p_val[] = {
@@ -96,6 +91,7 @@ void recv_msg_kexinit() {
 			buf_getptr(ses.transkexinit, ses.transkexinit->len),
 			ses.transkexinit->len);
 	buf_free(ses.transkexinit);
+	ses.transkexinit = NULL;
 	/* the rest of ses.kexhashbuf will be done after DH exchange */
 
 	ses.kexstate.recvkexinit = 1;
@@ -223,7 +219,7 @@ static void gen_new_keys() {
 			find_cipher(ses.newkeys->recv_algo_crypt->cipherdesc->name),
 			IV, key, keysize, 0, 
 			&ses.newkeys->recv_symmetric_struct) != CRYPT_OK) {
-		dropbear_exit("Crypto error");
+		dropbear_exit("crypto error");
 	}
 
 	/* server->client IV */
@@ -236,7 +232,7 @@ static void gen_new_keys() {
 			find_cipher(ses.newkeys->trans_algo_crypt->cipherdesc->name),
 			IV, key, keysize, 0, 
 			&ses.newkeys->trans_symmetric_struct) != CRYPT_OK) {
-		dropbear_exit("Crypto error");
+		dropbear_exit("crypto error");
 	}
 	/* MAC key client->server */
 	keysize = ses.newkeys->recv_algo_mac->keysize;
@@ -298,7 +294,7 @@ static void gen_new_keys() {
 		ret = deflateEnd(ses.keys->trans_zstream);
 		/* Z_DATA_ERROR is ok, just means that stream isn't ended */
 		if (ret == Z_STREAM_ERROR) {
-			dropbear_exit("Crypto error");
+			dropbear_exit("crypto error");
 		}
 		m_free(ses.keys->trans_zstream);
 	}
@@ -419,7 +415,7 @@ static void send_msg_kexdh_reply(mp_int *dh_e) {
 	sha1_process(&hs, buf_getptr(ses.kexhashbuf, ses.kexhashbuf->len),
 			ses.kexhashbuf->len);
 	sha1_done(&hs, ses.hash);
-#ifdef DEBUG_KEXHASH
+#if defined(DEBUG_KEXHASH) && defined(DEBUG_TRACE)
 	{
 		int hashfd;
 		int hashwritelen;
@@ -436,6 +432,7 @@ static void send_msg_kexdh_reply(mp_int *dh_e) {
 	}
 #endif /* DEBUG_KEXHASH */
 	buf_free(ses.kexhashbuf);
+	ses.kexhashbuf = NULL;
 	
 	/* first time around, we set the session_id to H */
 	if (!ses.session_id) {
@@ -494,7 +491,7 @@ static void read_kex() {
 	/* encryption_algorithms_client_to_server */
 	algo = buf_match_algo(ses.payload, sshciphers);
 	if (algo == NULL) {
-		erralgo = "encrypt client->server";
+		erralgo = "enc c->s";
 		goto error;
 	}
 	ses.newkeys->recv_algo_crypt = (struct dropbear_cipher*)algo->data;
@@ -502,7 +499,7 @@ static void read_kex() {
 	/* encryption_algorithms_server_to_client */
 	algo = buf_match_algo(ses.payload, sshciphers);
 	if (algo == NULL) {
-		erralgo = "encrypt server->client";
+		erralgo = "enc s->c";
 		goto error;
 	}
 	ses.newkeys->trans_algo_crypt = (struct dropbear_cipher*)algo->data;
@@ -510,7 +507,7 @@ static void read_kex() {
 	/* mac_algorithms_client_to_server */
 	algo = buf_match_algo(ses.payload, sshhashes);
 	if (algo == NULL) {
-		erralgo = "mac client->server";
+		erralgo = "mac c->s";
 		goto error;
 	}
 	ses.newkeys->recv_algo_mac = (struct dropbear_hash*)algo->data;
@@ -518,7 +515,7 @@ static void read_kex() {
 	/* mac_algorithms_server_to_client */
 	algo = buf_match_algo(ses.payload, sshhashes);
 	if (algo == NULL) {
-		erralgo = "mac server->client";
+		erralgo = "mac s->c";
 		goto error;
 	}
 	ses.newkeys->trans_algo_mac = (struct dropbear_hash*)algo->data;
@@ -526,7 +523,7 @@ static void read_kex() {
 	/* compression_algorithms_client_to_server */
 	algo = buf_match_algo(ses.payload, sshcompress);
 	if (algo == NULL) {
-		erralgo = "compress client->server";
+		erralgo = "comp c->s";
 		goto error;
 	}
 	ses.newkeys->recv_algo_comp = algo->val;
@@ -534,7 +531,7 @@ static void read_kex() {
 	/* compression_algorithms_server_to_client */
 	algo = buf_match_algo(ses.payload, sshcompress);
 	if (algo == NULL) {
-		erralgo = "compress server->client";
+		erralgo = "comp s->c";
 		goto error;
 	}
 	ses.newkeys->trans_algo_comp = algo->val;
@@ -554,7 +551,8 @@ static void read_kex() {
 	}
 
 	/* reserved for future extensions */
-	/*buf_getint(ses.payload);*/
+	/* buf_getint(ses.payload);*/
+
 	return;
 
 error:
@@ -609,7 +607,7 @@ void send_msg_kexinit() {
 
 	/* set up transmitted kex packet buffer for hashing. 
 	 * This is freed after the end of the kex */
-	ses.transkexinit = buf_newcopy(ses.writepayload, 1);
+	ses.transkexinit = buf_newcopy(ses.writepayload);
 
 	encrypt_packet();
 	ses.dataallowed = 0; /* don't send other packets during kex */
