@@ -22,12 +22,7 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE. */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <netinet/in.h>
-
-#include "options.h"
+#include "includes.h"
 #include "packet.h"
 #include "session.h"
 #include "util.h"
@@ -39,7 +34,6 @@
 #include "service.h"
 #include "auth.h"
 #include "channel.h"
-#include "libtomcrypt/mycrypt.h"
 
 static void read_packet_init();
 static void process_postauth_packet(unsigned int type);
@@ -195,14 +189,10 @@ static void read_packet_init() {
 
 	buf_setpos(ses.readbuf, blocksize);
 
-	/* check packet lengths */
-	if (len > MAX_PACKET_LEN) {
-		dropbear_exit("bad packet size");
-	}
-	if (len < MIN_PACKET_LEN + macsize) {
-		dropbear_exit("bad packet size");
-	}
-	if ((len - macsize) % blocksize != 0) {
+	/* check packet length */
+	if ((len > MAX_PACKET_LEN) ||
+		(len < MIN_PACKET_LEN + macsize) ||
+		((len - macsize) % blocksize != 0)) {
 		dropbear_exit("bad packet size");
 	}
 
@@ -302,10 +292,7 @@ void decrypt_packet() {
 	/* payload length */
 	/* - 4 - 1 is for LEN and PADLEN values */
 	len = ses.decryptreadbuf->len - padlen - 4 - 1;
-	if (len > MAX_PAYLOAD_LEN) {
-		dropbear_exit("bad packet size");
-	}
-	if (len < 1) { /* this is valid? */
+	if ((len > MAX_PAYLOAD_LEN) || (len < 1)) {
 		dropbear_exit("bad packet size");
 	}
 
@@ -410,8 +397,9 @@ void process_packet() {
 
 	/* check that we aren't expecting a particular packet */
 	if (ses.expecting && ses.expecting != type) {
-		/* TODO be more verbose, send disconnect? */
-		dropbear_exit("unexpected packet type %d", type);
+		/* TODO send disconnect? */
+		dropbear_exit("unexpected packet type %d, expected %d", type,
+				ses.expecting);
 	}
 
 	/* handle the packet depending on type */
@@ -439,12 +427,15 @@ void process_packet() {
 			recv_msg_newkeys();
 			break;
 
+		/* this is ugly, need to make a cleaner way to do it */
 		case SSH_MSG_CHANNEL_DATA:
 		case SSH_MSG_CHANNEL_WINDOW_ADJUST:
 		case SSH_MSG_CHANNEL_REQUEST:
 		case SSH_MSG_CHANNEL_OPEN:
 		case SSH_MSG_CHANNEL_EOF:
 		case SSH_MSG_CHANNEL_CLOSE:
+		case SSH_MSG_CHANNEL_OPEN_CONFIRMATION:
+		case SSH_MSG_CHANNEL_OPEN_FAILURE:
 			/* these should be checked for authdone below */
 			process_postauth_packet(type);
 			break;
@@ -496,6 +487,16 @@ static void process_postauth_packet(unsigned int type) {
 		case SSH_MSG_CHANNEL_CLOSE:
 			recv_msg_channel_close();
 			break;
+
+#ifdef USE_LISTENERS /* for x11, tcp fwd etc */
+		case SSH_MSG_CHANNEL_OPEN_CONFIRMATION:
+			recv_msg_channel_open_confirmation();
+			break;
+			
+		case SSH_MSG_CHANNEL_OPEN_FAILURE:
+			recv_msg_channel_open_failure();
+			break;
+#endif
 			
 		default:
 			TRACE(("unknown packet()"));
@@ -510,16 +511,12 @@ static void process_postauth_packet(unsigned int type) {
  * there is only a single decryption buffer */
 static void recv_unimplemented() {
 
-	unsigned int seq;
-
-	/* the decryption routine increments the sequence number, we must
-	 * decrement */
-	seq = ses.recvseq - 1;
-
 	CHECKCLEARTOWRITE();
 
 	buf_putbyte(ses.writepayload, SSH_MSG_UNIMPLEMENTED);
-	buf_putint(ses.writepayload, seq);
+	/* the decryption routine increments the sequence number, we must
+	 * decrement */
+	buf_putint(ses.writepayload, ses.recvseq - 1);
 
 	encrypt_packet();
 }
@@ -711,5 +708,3 @@ static void buf_compress(buffer * dest, buffer * src, unsigned int len) {
 	TRACE(("leave buf_compress"));
 }
 #endif
-
-
