@@ -25,12 +25,7 @@
 #ifndef _SESSION_H_
 #define _SESSION_H_
 
-#include <stdio.h>
-#ifndef DISABLE_ZLIB
-#include <zlib.h>
-#endif
-
-#include "options.h"
+#include "includes.h"
 #include "buffer.h"
 #include "signkey.h"
 #include "kex.h"
@@ -40,6 +35,7 @@
 #include "runopts.h"
 
 extern int sessinitdone;
+extern int exitflag;
 
 void session_cleanup();
 void child_session(int sock, runopts *opts, int childpipe,
@@ -78,6 +74,7 @@ struct sshsession {
 
 	struct sockaddr *remoteaddr; /* the host and port of the client */
 	unsigned char *addrstring; /* the text version of remoteaddr */
+	unsigned char *hostname; /* the remote hostname */
 
 	unsigned int maxfd; /* the maximum file descriptor to check with select() */
 	unsigned char *remoteident;
